# This file is being maintained by Puppet.
# DO NOT EDIT

<% if @pid_file != 'UNSET' -%>
pid file = <%= @pid_file %>
<% end -%>
uid = <%= @uid %>
gid = <%= @gid %>
use chroot = <%= @use_chroot %>
log format = %t %a %m %f %b
syslog facility = local3
timeout = 300
address = <%= @address %>
<% if @motd_file != 'UNSET' -%>
motd file = <%= @motd_file %>
<% end -%>
