[ <%= @name %> ]
path               = <%= @path %>
read only          = <%= @read_only %>
write only         = <%= @write_only %>
list               = <%= @list %>
<% if @uid -%>
uid                = <%= @uid %>
<% end -%>
<% if @gid -%>
gid                = <%= @gid %>
<% end -%>
<% if @numeric_ids -%>
numeric ids        = <%= @numeric_ids %>
<% end -%>
<% if @use_chroot -%>
use chroot         = <%= @use_chroot %>
<% end -%>
<% if @incoming_chmod -%>
incoming chmod     = <%= @incoming_chmod %>
<% end -%>
<% if @outgoing_chmod -%>
outgoing chmod     = <%= @outgoing_chmod %>
<% end -%>
<% if @max_connections -%>
max connections    = <%= @max_connections %>
<% end -%>
<% if @timeout -%>
timeout            = <%= @timeout %>
<% end -%>
<% if Integer(@max_connections) > 0 -%>
lock file          = <%= @lock_file %>
<% end -%>
<% if @comment -%>
comment            = <%= @comment %>
<% end -%>
<% if @secrets_file -%>
secrets file       = <%= @secrets_file %>
<% end -%>
<% if @auth_users -%>
auth users         = <%= Array(@auth_users).join(', ')%>
<% end -%>
<% if @hosts_allow -%>
hosts allow        = <%= Array(@hosts_allow).join(' ')%>
<% end -%>
<% if @hosts_deny -%>
hosts deny         = <%= Array(@hosts_deny).join(' ')%>
<% end -%>
<% if @transfer_logging -%>
transfer logging   = <%= @transfer_logging %>
<% end -%>
<% if @log_format -%>
log format         = <%= @log_format %>
<% end -%>
<% if @refuse_options -%>
refuse options     = <%= Array(@refuse_options).join(' ')%>
<% end -%>
<% if @ignore_nonreadable -%>
ignore nonreadable = <%= @ignore_nonreadable %>
<% end -%>
<% if @log_file -%>
log file = <%= @log_file %>
<% end -%>
<% if @include -%>
include            = <%= Array(@include).join(' ')%>
<% end -%>
<% if @include_from -%>
include from       = <%= @include_from%>
<% end -%>
<% if @exclude -%>
exclude            = <%= Array(@exclude).join(' ')%>
<% end -%>
<% if @exclude_from -%>
exclude from       = <%= @exclude_from%>
<% end -%>
<% if @dont_compress -%>
dont compress      = <%= Array(@dont_compress).join(' ')%>
<% end -%>
